; E2proM1
; =======
;
;File: E2proM1.asm
;Version: 1.0 - Feb/25/2013
;Author: TK90X Fan (reikainosuke-tk@yahoo.com.br, cantinhotk90x.blogspot.com)
;Description:
; E2proM1 writes 8192 bytes of data to Multiface 1 RAM (addresses 8192-16383). 
; If an 8KB E2PROM (EEPROM) is fitted instead of RAM, its contents will be
; overwritten. Thus this software may replace EPROM programmers using Multiface
; 1. 
;License: 
;    This program is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation, either version 3 of the License, or
;    (at your option) any later version.
;
;    This program is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
;------------------------------------------------------------------------------
;
; Headers
; -------
    INCLUDE 'Header_Print.asm'
;
;------------------------------------------------------------------------------
;
    ORG 32768
    JP Main                 ; Jump to main program.
;
;------------------------------------------------------------------------------
; Constants
; ---------
;
;------------------------------------------------------------------------------
; Variables
RomDataAdd: DEFW 40000      ; 32771. Start address of data to be written to
                            ;E2PROM.
M1PIPort:   DEFB 159        ; 32773. Port address that pages in M1 memory.
M1POPort:   DEFB 31         ; 32774. Port address that pages out M1 memory. 
Retries:    DEFW 1000       ; 32775. Number of attempts before giving up. 
E2promAdd:  DEFW 8192       ; 32777. Start address of M1 RAM.
;
;------------------------------------------------------------------------------
; Main program
Main:
    LD A,2                  ; Output will be redirected to channel 2, i.e. to
    CALL CHAN_OPEN          ;upper screen lines. 
    LD IX,(RomDataAdd)      ; Fetch address of first byte to write.
    LD HL,(E2promAdd)       ; Fetch address of first byte of E2PROM.
Main1:
    LD DE,Mess01            ; PRINT AT 8,1;"Address";
    LD BC,Mess02-Mess01
    CALL PR_STRING
    PUSH HL                 ; Real write address is saved. 
    LD DE,(E2promAdd)       ; Real write address is in 8192-16383 ($2000-$3FFF)
    AND A                   ;range but address of E2PROM bus is in 0-8191 ($0000
    SBC HL,DE               ;-$1FFF) range. Calculate E2PROM bus address and
    CALL PrintHL_h          ;print it in hexadecimal notation. 
    LD DE,Mess02            ; PRINT '" Value";
    LD BC,Mess03-Mess02
    CALL PR_STRING
    POP HL                  ; Restore real write address. 
    LD A,(IX+0)             ; Print value to write into E2PROM.
    CALL print_h
    LD DE,Mess03            ; Print '" Verifying...'
    LD BC,Mess04-Mess03
    CALL PR_STRING
    CALL M1PageIn           ; Page in M1 memory.
    LD A,(IX+0)             ; Fetch byte from Spectrum RAM and write to
    LD (HL),A               ;E2PROM. 
    LD DE,(Retries)         ; DE is counter for number of retries. 
Polling:
    PUSH DE                 ; Save number of retries onto stack. 
    LD B,0                  ; Wait for about 1 ms. 
Delay:
    DJNZ Delay
    EX AF,AF'               ; Save value that has been written to E2PROM.
    POP DE                  ; Get number of retries from stack. 
    DEC DE                  ; Decrement counter of retries. 
    LD A,D                  ; Give up data verifying if counter reached 0. 
    OR E
    JR Z,Error
    EX AF,AF'               ; Restore value that has been written to E2PROM.
    CP (HL)                 ; Same value as the written data is read from E2PROM
    JR NZ,Polling           ;just after write cycle was completed. 
    CALL M1PageOut          ; Return memory page to Spectrum ROM. 
    INC IX                  ; Increment pointers.
    INC HL
    LD A,H
    SUB 16384/256           ; The address of last byte to be written is 16383. 
    JR NZ,Main1             ; Repeat if address was not 16384.
    LD B,A                  ; USR must return 0 to signal successful completion. 
    LD C,B
    RET                     ; End of main program.
;
Error:
    LD A,(HL)               ; Read from E2PROM and save onto stack. 
    PUSH AF
    CALL M1PageOut          ; Page in Spectrum ROM. 
    LD DE,Mess04            ; Print '' FLASH 1; " ERROR! "; FLASH 0; "Value
    LD BC,Mess05-Mess04     ;read from E2PROM: '
    CALL PR_STRING
    POP AF                  ; Fetch from stack value read from E2PROM. 
    LD C,255                ; USR must return nonzero value to signal error. 
    JP print_h              ; Print value and return to BASIC. 
;
;------------------------------------------------------------------------------
; Strings
Mess01:
    DEFB Pr_At,8,1
    DEFM 'Address: '
Mess02:
    DEFB Enter
    DEFM ' Value: '
Mess03:
    DEFB Enter
    DEFM ' Verifying...'
Mess04:
    DEFB Enter, Enter, Pr_Flash, 1
    DEFM ' ERROR! '
    DEFB Pr_Flash, 0, Enter
    DEFM ' Value read from E2PROM: '
Mess05: 
;
;------------------------------------------------------------------------------
; Sub-routines
;------------------------------------------------------------------------------
; Page in M1 memory
; -----------------
M1PageIn:
    DI
    LD A,(M1PIPort)
    LD C,A
    IN A,(C)
    RET
; Page out M1 memory
; ------------------
M1PageOut:
    LD A,(M1POPort)
    LD C,A
    IN A,(C)
    EI
    RET
;
; Print HL as hexadecimal number
; ------------------------------
PrintHL_h:
    LD A,H                  ; Print most significant byte first,
    CALL print_h
    LD A,L                  ;followed by least significant byte. 
;
; Print byte in A as hexadecimal number
; =====================================
; Label: print_h
; Input: A=value to be printed
print_h:
        PUSH AF             ; Save A.
        RLCA                ; Transfer most significant nibble (MSN) into
        RLCA                ;least significant nibble (LSN).
        RLCA
        RLCA
        CALL .print_h1      ; Print MSN.
        POP AF              ; Recover A value and repeat to print LSN. 
.print_h1:
        AND %00001111       ; Reset all MSN bits.
        OR  %00110000       ; Converts digit to ASCII.
        CP '9'+1            ; If A was equal to or less than '9'
        JR C,.print_h2      ;jump the next instruction.
        ADD A,7             ; Put A into 'A'-'F' range. 
.print_h2:
        RST 16              ; Print hexadecimal digit. 
        RET                 ; End of sub-routine.

